@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/ed.screen.c,v 3.46 1999/02/06 15:18:56 christos Exp $ */
+/* $Header: /src/pub/tcsh/ed.screen.c,v 3.47 2000/06/11 02:14:12 kim Exp $ */
 /*
  * ed.screen.c: Editor/termcap-curses interface
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: ed.screen.c,v 3.46 1999/02/06 15:18:56 christos Exp $")
+RCSID("$Id: ed.screen.c,v 3.47 2000/06/11 02:14:12 kim Exp $")
 
 #include "ed.h"
 #include "tc.h"
@@ -843,7 +843,7 @@ DefaultArrowKeys()
     static Char stOD[] = {033, 'O', 'D', '\0'};
 
     CStr cs;
-#ifdef _OSD_POSIX
+#ifndef IS_ASCII
     if (strA[0] == 033)
     {
 	strA[0] = CTL_ESC('\033');
