@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/sh.exec.c,v 3.47 1999/04/20 07:48:44 christos Exp $ */
+/* $Header: /src/pub/tcsh/sh.exec.c,v 3.50 2000/07/15 19:58:50 christos Exp $ */
 /*
  * sh.exec.c: Search, find, and execute a command!
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.exec.c,v 3.47 1999/04/20 07:48:44 christos Exp $")
+RCSID("$Id: sh.exec.c,v 3.50 2000/07/15 19:58:50 christos Exp $")
 
 #include "tc.h"
 #include "tw.h"
@@ -147,7 +147,7 @@ static Char *justabs[] = {STRNULL, 0};
 
 static	void	pexerr		__P((void));
 static	void	texec		__P((Char *, Char **));
-static	int	hashname	__P((Char *));
+int	hashname	__P((Char *));
 static	int 	iscommand	__P((Char *));
 
 void
@@ -751,7 +751,7 @@ dohash(vv, c)
 #ifdef WINNT
 	    nt_check_name_and_hash(is_windir, dp->d_name, i);
 #else /* !WINNT */
-#if defined(_UWIN) /* XXX: Add cygwin too */
+#if defined(_UWIN) || defined(__CYGWIN__)
 	    /* Turn foo.{exe,com,bat} into foo since UWIN's readdir returns
 	     * the file with the .exe, .com, .bat extension
 	     */
@@ -762,7 +762,7 @@ dohash(vv, c)
 				  strcmp(&dp->d_name[ext], ".com") == 0))
 		    dp->d_name[ext] = '\0';
 	    }
-#endif /* _UWIN */
+#endif /* _UWIN || __CYGWIN__ */
 # ifdef FASTHASH
 	    hashval = hashname(str2short(dp->d_name));
 	    bis(hashval, i);
@@ -823,11 +823,11 @@ hashstat(v, c)
 /*
  * Hash a command name.
  */
-static int
+int
 hashname(cp)
     register Char *cp;
 {
-    register long h;
+    register unsigned long h;
 
     for (h = 0; *cp; cp++)
 	h = hash(h, *cp);
@@ -893,6 +893,7 @@ cont:
  * Thanks again!!
  */
 
+#ifndef WINNT
 /*
  * executable() examines the pathname obtained by concatenating dir and name
  * (dir may be NULL), and returns 1 either if it is executable by us, or
@@ -907,37 +908,11 @@ executable(dir, name, dir_ok)
     struct stat stbuf;
     Char    path[MAXPATHLEN + 1];
     char   *strname;
-#ifdef WINNT
-    int	    nt_exetype;
-#endif /* WINNT */
     (void) memset(path, 0, sizeof(path));
 
     if (dir && *dir) {
 	copyn(path, dir, MAXPATHLEN);
 	catn(path, name, MAXPATHLEN);
-#ifdef WINNT
-	{
-	    char *ptr = short2str(path);
-	    char *p2 = ptr;
-	    int has_ext = 0;
-
-	    while (*ptr++)
-		continue;
-	    --ptr;
-
-	    while(ptr > p2) { 
-		if (*ptr == '/')
-		    break;
-		if (*ptr == '.') {
-		    has_ext = 1;
-		    break;
-		}
-		ptr--;
-	    }
-	    if (!has_ext && (stat(p2, &stbuf) == -1))
-		catn(path, STRdotEXE, MAXPATHLEN);
-	}
-#endif /* WINNT */
 	strname = short2str(path);
     }
     else
@@ -947,15 +922,11 @@ executable(dir, name, dir_ok)
 	    ((dir_ok && S_ISDIR(stbuf.st_mode)) ||
 	     (S_ISREG(stbuf.st_mode) &&
     /* save time by not calling access() in the hopeless case */
-#ifdef WINNT
-	      (GetBinaryType(strname,&nt_exetype) ||
-	      (stbuf.st_mode & (S_IXOTH | S_IXGRP | S_IXUSR)))
-#else /* !WINNT */
 	      (stbuf.st_mode & (S_IXOTH | S_IXGRP | S_IXUSR)) &&
 	      access(strname, X_OK) == 0
-#endif /* WINNT */
 	)));
 }
+#endif /*!WINNT*/
 
 int
 tellmewhat(lexp, str)
@@ -1200,54 +1171,7 @@ find_cmd(cmd, prt)
     xfree((ptr_t) sv);
     return rval;
 }
-
 #ifdef WINNT
-int
-nt_check_if_windir(path)
-    char *path;
-{
-    char windir[MAX_PATH];
-
-    (void)GetWindowsDirectory(windir, sizeof(windir));
-    windir[2] = '/';
-
-    return (strstr(path, windir) != NULL);
-}
-
-void
-nt_check_name_and_hash(is_windir, file, i)
-    int is_windir;
-    char *file;
-    int i;
-{
-    char name_only[MAX_PATH];
-    char *tmp = (char *)strrchr(file, '.');
-    char uptmp[5], *nameptr, *np2;
-    int icount, hashval;
-
-    if(!tmp || tmp[4]) 
-	goto nodot;
-
-    for (icount = 0; icount < 4; icount++)
-	uptmp[icount] = toupper(tmp[icount]);
-    uptmp[4]=0;
-
-    if (is_windir)
-	if((uptmp[1] != 'E') || (uptmp[2] != 'X') || (uptmp[3] != 'E'))
-	    return;
-    (void) memset(name_only, 0, MAX_PATH);
-    nameptr = file;
-    np2 = name_only;
-    while(nameptr != tmp) {
-	*np2++= tolower(*nameptr);
-	nameptr++;
-    }
-    hashval = hashname(str2short(name_only));
-    bis(hashval, i);
-nodot:
-    hashval = hashname(str2short(file));
-    bis(hashval, i);
-}
 int hashval_extern(cp)
 	Char *cp;
 {
@@ -1259,4 +1183,11 @@ int bit_extern(val,i)
 {
 	return bit(val,i);
 }
+void bis_extern(val,i)
+	int val;
+	int i;
+{
+	bis(val,i);
+}
 #endif /* WINNT */
+
