@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/sh.lex.c,v 3.49 1998/04/08 13:58:54 christos Exp $ */
+/* $Header: /src/pub/tcsh/sh.lex.c,v 3.51 2000/07/04 19:42:47 christos Exp $ */
 /*
  * sh.lex.c: Lexical analysis into tokens
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.lex.c,v 3.49 1998/04/08 13:58:54 christos Exp $")
+RCSID("$Id: sh.lex.c,v 3.51 2000/07/04 19:42:47 christos Exp $")
 
 #include "ed.h"
 /* #define DEBUG_INP */
@@ -97,7 +97,7 @@ static struct wordent *exclnxt = NULL;
 static int exclc = 0;
 
 /* "Globp" for alias resubstitution */
-int aret = F_SEEK;
+int aret = TCSH_F_SEEK;
 
 /*
  * Labuf implements a general buffer for lookahead during lexical operations.
@@ -295,6 +295,9 @@ word()
     int	    h;
     bool dolflg;
     int i;
+#if defined(DSPMBYTE)
+    int mbytepos = 1;
+#endif /* DSPMBYTE */
 
     wp = wbuf;
     i = BUFSIZE - 4;
@@ -355,6 +358,13 @@ loop:
     c1 = 0;
     dolflg = DOALL;
     for (;;) {
+#if defined(DSPMBYTE)
+        if (mbytepos == 2)
+	    mbytepos = 1;
+	else if (mbytepos == 1 && Ismbyte1(c) && 2 <= i)
+	    mbytepos = 2;
+	else
+#endif /* DSPMBYTE */
 	if (c1) {
 	    if (c == c1) {
 		c1 = 0;
@@ -1494,13 +1504,13 @@ readc(wanteof)
     if (numeof < 1) numeof = 26;	/* Sanity check */
 
 top:
-    aret = F_SEEK;
+    aret = TCSH_F_SEEK;
     if (alvecp) {
 	arun = 1;
 #ifdef DEBUG_INP
 	xprintf("alvecp %c\n", *alvecp & 0xff);
 #endif
-	aret = A_SEEK;
+	aret = TCSH_A_SEEK;
 	if ((c = *alvecp++) != 0)
 	    return (c);
 	if (alvec && *alvec) {
@@ -1509,7 +1519,7 @@ top:
 	}
 	else {
 	    alvecp = NULL;
-	    aret = F_SEEK;
+	    aret = TCSH_F_SEEK;
 	    return('\n');
 	}
     }
@@ -1524,14 +1534,14 @@ top:
     }
     arun = 0;
     if (evalp) {
-	aret = E_SEEK;
+	aret = TCSH_E_SEEK;
 	if ((c = *evalp++) != 0)
 	    return (c);
 	if (evalvec && *evalvec) {
 	    evalp = *evalvec++;
 	    return (' ');
 	}
-	aret = F_SEEK;
+	aret = TCSH_F_SEEK;
 	evalp = 0;
     }
     if (evalvec) {
@@ -1800,21 +1810,21 @@ bseek(l)
     struct Ain   *l;
 {
     switch (aret = l->type) {
-    case E_SEEK:
+    case TCSH_E_SEEK:
 	evalvec = l->a_seek;
 	evalp = l->c_seek;
 #ifdef DEBUG_SEEK
 	xprintf(CGETS(16, 4, "seek to eval %x %x\n"), evalvec, evalp);
 #endif
 	return;
-    case A_SEEK:
+    case TCSH_A_SEEK:
 	alvec = l->a_seek;
 	alvecp = l->c_seek;
 #ifdef DEBUG_SEEK
 	xprintf(CGETS(16, 5, "seek to alias %x %x\n"), alvec, alvecp);
 #endif
 	return;
-    case F_SEEK:	
+    case TCSH_F_SEEK:	
 #ifdef DEBUG_SEEK
 	xprintf(CGETS(16, 6, "seek to file %x\n"), fseekp);
 #endif
@@ -1832,21 +1842,21 @@ btell(l)
 struct Ain *l;
 {
     switch (l->type = aret) {
-    case E_SEEK:
+    case TCSH_E_SEEK:
 	l->a_seek = evalvec;
 	l->c_seek = evalp;
 #ifdef DEBUG_SEEK
 	xprintf(CGETS(16, 8, "tell eval %x %x\n"), evalvec, evalp);
 #endif
 	return;
-    case A_SEEK:
+    case TCSH_A_SEEK:
 	l->a_seek = alvec;
 	l->c_seek = alvecp;
 #ifdef DEBUG_SEEK
 	xprintf(CGETS(16, 9, "tell alias %x %x\n"), alvec, alvecp);
 #endif
 	return;
-    case F_SEEK:
+    case TCSH_F_SEEK:
 	/*SUPPRESS 112*/
 	l->f_seek = fseekp;
 	l->a_seek = NULL;
@@ -1864,7 +1874,7 @@ void
 btoeof()
 {
     (void) lseek(SHIN, (off_t) 0, L_XTND);
-    aret = F_SEEK;
+    aret = TCSH_F_SEEK;
     fseekp = feobp;
     alvec = NULL;
     alvecp = NULL;
