@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/tc.prompt.c,v 3.36 1999/02/06 15:19:04 christos Exp $ */
+/* $Header: /src/pub/tcsh/tc.prompt.c,v 3.39 2000/06/10 19:20:01 kim Exp $ */
 /*
  * tc.prompt.c: Prompt printing stuff
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tc.prompt.c,v 3.36 1999/02/06 15:19:04 christos Exp $")
+RCSID("$Id: tc.prompt.c,v 3.39 2000/06/10 19:20:01 kim Exp $")
 
 #include "ed.h"
 #include "tw.h"
@@ -186,9 +186,10 @@ tprintf(what, buf, fmt, siz, str, tim, info)
     Char   *z, *q;
     Char    attributes = 0;
     static int print_prompt_did_ding = 0;
-    const char   *cz;
     Char    buff[BUFSIZE];
-    char    cbuff[BUFSIZE];
+    /* Need to be unsigned to avoid sign extension */
+    const unsigned char   *cz;
+    unsigned char    cbuff[BUFSIZE];
 
     Char *p  = buf;
     Char *ep = &p[siz];
@@ -205,14 +206,24 @@ tprintf(what, buf, fmt, siz, str, tim, info)
     for (; *cp; cp++) {
 	if (p >= ep)
 	    break;
+#ifdef DSPMBYTE
+	if (Ismbyte1(*cp) && ! (cp[1] == '\0'))
+	{
+	    *p++ = attributes | *cp++;	/* normal character */
+	    *p++ = attributes | *cp;	/* normal character */
+	}
+	else
+#endif /* DSPMBYTE */
 	if ((*cp == '%') && ! (cp[1] == '\0')) {
 	    cp++;
 	    switch (*cp) {
 	    case 'R':
 		if (what == FMT_HISTORY)
-		    fmthist('R', info, str = cbuff, sizeof(cbuff));
-		if (str != NULL)
-		    for (; *str; *p++ = attributes | *str++)
+		    fmthist('R', info, (char *) (cz = cbuff), sizeof(cbuff));
+		else
+		    cz = (unsigned char *) str;
+		if (cz != NULL)
+		    for (; *cz; *p++ = attributes | *cz++)
 			if (p >= ep) break;
 		break;
 	    case '#':
@@ -225,10 +236,12 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 		    fmthist('h', info, (char *) cbuff, sizeof(cbuff));
 		    break;
 		case FMT_SCHED:
-		    (void) xsnprintf((char *) cbuff, sizeof(cbuff), "%d", *(int *)info);
+		    (void) xsnprintf((char *) cbuff, sizeof(cbuff), "%d", 
+			*(int *)info);
 		    break;
 		default:
-		    (void) xsnprintf((char *) cbuff, sizeof(cbuff), "%d", eventno + 1);
+		    (void) xsnprintf((char *) cbuff, sizeof(cbuff), "%d",
+			eventno + 1);
 		    break;
 		}
 		for (cz = cbuff; *cz; *p++ = attributes | *cz++)
@@ -289,10 +302,11 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 	    case 'M':
 #ifndef HAVENOUTMP
 		if (what == FMT_WHO)
-		    cz = who_info(info, 'M', (char *) cbuff, sizeof(cbuff));
+		    cz = (unsigned char *) who_info(info, 'M',
+			(char *) cbuff, sizeof(cbuff));
 		else 
 #endif /* HAVENOUTMP */
-		    cz = getenv("HOST");
+		    cz = (unsigned char *) getenv("HOST");
 		/*
 		 * Bug pointed out by Laurent Dami <dami@cui.unige.ch>: don't
 		 * derefrence that NULL (if HOST is not set)...
@@ -305,10 +319,11 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 	    case 'm':
 #ifndef HAVENOUTMP
 		if (what == FMT_WHO)
-		    cz = who_info(info, 'm', (char *) cbuff, sizeof(cbuff));
+		    cz = (unsigned char *) who_info(info, 'm', (char *) cbuff,
+			sizeof(cbuff));
 		else 
 #endif /* HAVENOUTMP */
-		    cz = getenv("HOST");
+		    cz = (unsigned char *) getenv("HOST");
 
 		if (cz != NULL)
 		    for ( ; *cz && (what == FMT_WHO || *cz != '.')
@@ -421,7 +436,8 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 	    case 'n':
 #ifndef HAVENOUTMP
 		if (what == FMT_WHO) {
-		    cz = who_info(info, 'n', (char *) cbuff, sizeof(cbuff));
+		    cz = (unsigned char *) who_info(info, 'n',
+			(char *) cbuff, sizeof(cbuff));
 		    for (; cz && *cz ; *p++ = attributes | *cz++)
 			if (p >= ep) break;
 		}
@@ -436,7 +452,8 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 	    case 'l':
 #ifndef HAVENOUTMP
 		if (what == FMT_WHO) {
-		    cz = who_info(info, 'l', (char *) cbuff, sizeof(cbuff));
+		    cz = (unsigned char *) who_info(info, 'l',
+			(char *) cbuff, sizeof(cbuff));
 		    for (; cz && *cz ; *p++ = attributes | *cz++)
 			if (p >= ep) break;
 		}
@@ -449,7 +466,8 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 		}
 		break;
 	    case 'd':
-		for (cz = day_list[t->tm_wday]; *cz; *p++ = attributes | *cz++)
+		for (cz = (unsigned char *) day_list[t->tm_wday]; *cz;
+		    *p++ = attributes | *cz++)
 		    if (p >= ep) break;
 		break;
 	    case 'D':
@@ -458,8 +476,9 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 		break;
 	    case 'w':
 		if (p >= ep - 5) break;
-		for (cz = month_list[t->tm_mon]; *cz;)
-		    *p++ = attributes | *cz++;
+		for (cz = (unsigned char *) month_list[t->tm_mon]; *cz;
+		    *p++ = attributes | *cz++)
+		    if (p >= ep) break;
 		break;
 	    case 'W':
 		if (p >= ep - 3) break;
