@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/tw.parse.c,v 3.86 1998/10/25 15:10:52 christos Exp $ */
+/* $Header: /src/pub/tcsh/tw.parse.c,v 3.88 2000/06/11 02:14:17 kim Exp $ */
 /*
  * tw.parse.c: Everyone has taken a shot in this futile effort to
  *	       lexically analyze a csh line... Well we cannot good
@@ -39,7 +39,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tw.parse.c,v 3.86 1998/10/25 15:10:52 christos Exp $")
+RCSID("$Id: tw.parse.c,v 3.88 2000/06/11 02:14:17 kim Exp $")
 
 #include "tw.h"
 #include "ed.h"
@@ -109,7 +109,9 @@ extern int lbuffed;		/* from sh.print.c */
 static	void	 extract_dir_and_name	__P((Char *, Char *, Char *));
 static	int	 insert_meta		__P((Char *, Char *, Char *, bool));
 static	Char	*tilde			__P((Char *, Char *));
+#ifndef __MVS__
 static  int      expand_dir		__P((Char *, Char *, DIR  **, COMMAND));
+#endif
 static	bool	 nostat			__P((Char *));
 static	Char	 filetype		__P((Char *, Char *));
 static	int	 t_glob			__P((Char ***, int));
@@ -120,10 +122,12 @@ static	int	 is_suffix		__P((Char *, Char *));
 static	int	 recognize		__P((Char *, Char *, int, int, int));
 static	int	 ignored		__P((Char *));
 static	int	 isadirectory		__P((Char *, Char *));
+#ifndef __MVS__
 static  int      tw_collect_items	__P((COMMAND, int, Char *, Char *, 
 					     Char *, Char *, int));
 static  int      tw_collect		__P((COMMAND, int, Char *, Char *, 
 					     Char **, Char *, int, DIR *));
+#endif
 static	Char 	 tw_suffix		__P((int, Char *, Char *, Char *, 
 					     Char *));
 static	void 	 tw_fixword		__P((int, Char *, Char *, Char *, int));
@@ -529,6 +533,9 @@ insert_meta(cp, cpend, word, closequotes)
     int qu = 0;
     int ndel = (int) (cp ? cpend - cp : 0);
     Char w, wq;
+#ifdef DSPMBYTE
+    int mbytepos = 1;
+#endif /* DSPMBYTE */
 
     for (bptr = buffer, wptr = word;;) {
 	if (bptr > buffer + 2 * FILSIZ - 5)
@@ -536,6 +543,9 @@ insert_meta(cp, cpend, word, closequotes)
 	  
 	if (cp >= cpend)
 	    in_sync = 0;
+#ifdef DSPMBYTE
+	if (mbytepos == 1)
+#endif /* DSPMBYTE */
 	if (in_sync && !cmap(qu, _ESC) && cmap(*cp, _QF|_ESC))
 	    if (qu == 0 || qu == *cp) {
 		qu ^= *cp;
@@ -549,6 +559,10 @@ insert_meta(cp, cpend, word, closequotes)
 	wq = w & QUOTE;
 	w &= ~QUOTE;
 
+#ifdef DSPMBYTE
+	if (mbytepos == 2)
+	  goto mbyteskip;
+#endif /* DSPMBYTE */
 	if (cmap(w, _ESC | _QF))
 	    wq = QUOTE;		/* quotes are always quoted */
 
@@ -590,9 +604,18 @@ insert_meta(cp, cpend, word, closequotes)
 	    *bptr++ = '\\';
 	    *bptr++ = w;
 	} else {
+#ifdef DSPMBYTE
+	  mbyteskip:
+#endif /* DSPMBYTE */
 	    if (in_sync && *cp++ != w)
 		in_sync = 0;
 	    *bptr++ = w;
+#ifdef DSPMBYTE
+	    if (mbytepos == 1 && Ismbyte1(w))
+	      mbytepos = 2;
+	    else
+	      mbytepos = 1;
+#endif /* DSPMBYTE */
 	}
 	wptr++;
 	if (cmap(qu, _ESC))
